/**
 * Fichier : utilitaires.h
 * Auteur : Pascal Chour - www.pascalchour.fr
 * Date : 15 septembre 2019
 * (c) Pascal Chour 
 *-------------------------------------------------------------------------- 
 */

#ifndef UTILITAIRES_H
#define UTILITAIRES_H
#include <msp430fr6989.h>
#include "stdint.h"
#include "driverlib/MSP430FR5xx_6xx/driverlib.h"


/*
 * Dure d'un signal d'alarme (identique pour LED et buzzer). Pour l'alarme LED, on clignote toutes les PERIODE_LED
 * Pour le Buzzer, on met 2 coups bref puis on attend, puis on recommence
 */
#define PERIODE_1ms (33)            // Priode du compteur A0 pour environ 1ms (par rapport  ACLK = 32768Hz)
#define DUREE_SIGNAL_ALARME (50)    // Dure d'un signal en ms
#define PERIODE_LED_BUZ (1000)      // Dlai entre deux flash ou double bips en ms
#define DELAI_BUZ (100)             // Pour faire 2 bips proches en ms
#define KB_TEMPO (1)                // Dure de l'inversion en ms. Doit tre suprieur  0.

// Etat automate pour signalement alarme
// E_ALARME0  Etat d'entre. Initialisation variable d'tat
// E_ALARME1  On active la LED et/ou le buzzer, on initialise le timer pour la dure d'activation
// E_ALARME2  On dsactive la LED et/ou le buzzer. On initialise le timer pour le buzzer pour la dure de dsactivation
// E_ALARME3  On active le buzzer. On initialise le timer pour la dure d'activation.
// E_ALARME4  on dsactive le buzzer. On initialise le timer pour le dlai entre deux signaux -> E_ALARME1

enum {E_ALARME0,E_ALARME1,E_ALARME2,E_ALARME3,E_ALARME4};


uint16_t max16(uint16_t a,uint16_t b);
void Uint16Ascii(uint16_t Valeur, char T[]);
void SleepMS(uint16_t Nb);
void InitGenerale(void);
void InitialiseES();
void PileESPUSH(uint8_t Commande);
bool LireCar(uint8_t *c);
void TensionBatterie();

#endif /* UTILITAIRES_H */

/* END OF FILE */
